@@ -1,18 +1,17 @@
 /* **************************************************** teo2gdk-pixbuf.h *** *
  * TEOGdkPixbufȤѴؿ إåե
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-09-19 23:29:32 sugaya>
+ *                                  Time-stamp: <05/06/27 17:23:27 sugaya>
  * ************************************************************************* */
 #ifndef __TEO2GDK_PIXBUF_H__
 #define __TEO2GDK_PIXBUF_H__
 
-GdkPixbuf*	teo2gdk_pixbuf_new_from_teoimage (TEOIMAGE	*img,
-						  double	min,
-						  double	max);
+GdkPixbuf*	Teo2GdkPixbuf_new_from_teoimage (TEOIMAGE	*img,
+						 gboolean	normalize);
 
-TEOIMAGE*	teo2gdk_pixbuf_new_from_pixbuf 	(GdkPixbuf	*src, 
+TEOIMAGE*	Teo2GdkPixbuf_new_from_pixbuf 	(GdkPixbuf	*src, 
 						 gboolean	remove_alpha);
 
 #endif /* __TEO2GDK_PIXBUF_H__ */
