@@ -1,14 +1,15 @@
 /* ********************************************************* assistant.c *** *
  * Ȥ˴ؤؿ
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <04/06/21 23:56:46 sugaya>
+ *                                    Time-stamp: <05/05/24 14:31:10 sugaya>
  * ************************************************************************* */
 #include <gdk/gdkkeysyms.h>
 #include <libgtkhtml/gtkhtml.h>
 #include "teoeyes.h"
 #include "assistant.h"
+#include "glib-fileutil-extension.h"
 
 /* ************************************************************************* */
 static void	cb_html_destroy		(GtkWidget	*widget,
@@ -177,16 +178,16 @@ html_window_new (void) {
   GtkWidget		*menubar;
   GtkWidget		*toolbar;
   GtkWidget		*button;
+  GtkWidget		*widget;
   GtkWidget		*html_widget;
   GtkItemFactory	*item_factory;
   GtkAccelGroup		*accel_group;
   gint			nmenu_items;
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_wmclass (GTK_WINDOW (window), "teoeyes", "Teo Image Viewer");
   gtk_window_set_title (GTK_WINDOW (window), _("TeoEyes HTML Browser"));
   gtk_window_set_resizable (GTK_WINDOW (window), TRUE);
-  gtk_window_set_icon (GTK_WINDOW (window), te_icon);
+  gtk_window_set_icon (GTK_WINDOW (window), teoeyes_icon);
   g_signal_connect (G_OBJECT (window),
 		    "destroy", G_CALLBACK (cb_html_destroy), NULL);
   g_signal_connect (G_OBJECT (window),
@@ -194,7 +195,7 @@ html_window_new (void) {
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
-  G_SET_WIDGET (window, "vbox1", vbox);
+  G_SET_OBJECT(window, "vbox1", vbox);
   {
     /* ˥塼С */
     nmenu_items  = sizeof (menu_items) / sizeof (menu_items[0]);
@@ -210,36 +211,39 @@ html_window_new (void) {
 
     menubar = gtk_item_factory_get_widget (item_factory, "<main>");
     gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
-    G_SET_WIDGET (window, "menubar", menubar);
+    G_SET_OBJECT (window, "menubar", menubar);
 
     /* ġС */
     toolbar = gtk_toolbar_new ();
     gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
-    G_SET_WIDGET (window, "toolbar", toolbar);
+    G_SET_OBJECT (window, "toolbar", toolbar);
    
     button = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar),
 				       GTK_STOCK_GO_BACK, NULL, NULL,
 				       G_CALLBACK (cb_html_go_back), NULL, -1);
     gtk_widget_set_sensitive (button, FALSE);
-    G_SET_WIDGET (window, "back_button", button);
+    G_SET_OBJECT (window, "back_button", button);
 
     button = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar),
 				       GTK_STOCK_GO_FORWARD, NULL, NULL,
 				       G_CALLBACK (cb_html_go_forward), 
 				       NULL, -1);
     gtk_widget_set_sensitive (button, FALSE);    
-    G_SET_WIDGET (window, "forward_button", button);
+    G_SET_OBJECT (window, "forward_button", button);
  
     gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar),
 			      GTK_STOCK_INDEX, NULL, NULL,
 			      G_CALLBACK (cb_html_go_index), NULL, -1);
 
+    widget = gtk_hseparator_new();
+    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 3);
+    
     /* HTMLɥ */
     document = dh_html_new ();	
     html_widget = dh_html_get_widget (document);
     gtk_box_pack_start (GTK_BOX (vbox), html_widget, TRUE, TRUE, 0);
     g_object_set_data (G_OBJECT (window), "document", document);
-    G_SET_WIDGET (window, "html_widget", html_widget);
+    G_SET_OBJECT (window, "html_widget", html_widget);
   }
   return window;
 }
@@ -311,7 +315,7 @@ static void
 assistant_cb_msg_query (GtkWidget	*widget,
 			gpointer	*data) {
   GtkEntry	*entry;
-  GList		*list;
+  GSList	*list;
   FILE		*src_fp, *dst_fp;
   gchar		*cmd, *keyword, *file, *euc_file, *uri;
   gchar		*euc_tag = "<meta content=\"text/html; charset=EUC-JP\" http-equiv=\"Content-Type\">";
@@ -326,13 +330,12 @@ assistant_cb_msg_query (GtkWidget	*widget,
   if (!keyword) return;
 
   /* ̽ϥե(ƥݥ) */
-  file = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-		      CONFIG_FILE_DIR, G_DIR_SEPARATOR_S,
-		      "tmp.html", NULL);
+  file = g_build_filename (g_get_home_dir(), ".teoeyes/tmp.html", NULL);
   if (!file) return;
  
   /* ޥɤĹ׻ */
-  for (list = tc->assistant_doc_dirs, n = 0; list; list = g_list_next(list)) {
+  for (list = tc->assistant_doc_folders, n = 0;
+       list; list = g_slist_next(list)) {
     n += strlen (list->data) + 1;
   }
   n += strlen (file) + 1;
@@ -345,8 +348,8 @@ assistant_cb_msg_query (GtkWidget	*widget,
   }
   /* ޥɤ¹ */
   sprintf (cmd, "namazu -h -o %s %s", file, keyword);
-  for (list = tc->assistant_doc_dirs, n = strlen (cmd); list;
-       list = g_list_next (list)) {
+  for (list = tc->assistant_doc_folders, n = strlen (cmd); list;
+       list = g_slist_next (list)) {
     strcat (cmd + n, " ");
     strcat (cmd + n + 1, list->data);
     n += strlen (list->data) + 1;
@@ -361,9 +364,8 @@ assistant_cb_msg_query (GtkWidget	*widget,
     g_free (file);
     return;
   }
-  euc_file = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S,
-			  CONFIG_FILE_DIR, G_DIR_SEPARATOR_S,
-			  "search_result.html", NULL);
+  euc_file = g_build_filename (g_get_home_dir(), ".teoeyes/search_result.html",
+			       NULL);
   if (!euc_file) {
     g_free (file);
     fclose (src_fp);
@@ -518,7 +520,7 @@ assistant_msgbox_new (GtkWidget		*parent,
   table = gtk_table_new (3, 3, FALSE);
   gtk_widget_show (table);
   gtk_container_add (GTK_CONTAINER (msgbox), table);
-  G_SET_WIDGET (parent, "table", table);
+  G_SET_OBJECT (parent, "table", table);
 
   /* Х */
   canvas = gtk_drawing_area_new ();
@@ -527,7 +529,7 @@ assistant_msgbox_new (GtkWidget		*parent,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
   assistant_attach_skin (canvas, skin->msg_box[0]);
-  G_SET_WIDGET (msgbox, "canvas_left", canvas);
+  G_SET_OBJECT (msgbox, "canvas_left", canvas);
 			    
   canvas = gtk_drawing_area_new ();
   gtk_widget_ref (canvas);
@@ -536,7 +538,7 @@ assistant_msgbox_new (GtkWidget		*parent,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
   assistant_attach_skin (canvas, skin->msg_box[1]);  
-  G_SET_WIDGET (msgbox, "canvas_right", canvas);
+  G_SET_OBJECT (msgbox, "canvas_right", canvas);
   
   canvas = gtk_drawing_area_new ();
   gtk_widget_ref (canvas);
@@ -545,7 +547,7 @@ assistant_msgbox_new (GtkWidget		*parent,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
   assistant_attach_skin (canvas, skin->msg_box[2]);    
-  G_SET_WIDGET (msgbox, "canvas_top", canvas);
+  G_SET_OBJECT (msgbox, "canvas_top", canvas);
 
   canvas = gtk_drawing_area_new ();
   gtk_widget_ref (canvas);
@@ -554,7 +556,7 @@ assistant_msgbox_new (GtkWidget		*parent,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
   assistant_attach_skin (canvas, skin->msg_box[3]);
-  G_SET_WIDGET (msgbox, "canvas_bottom", canvas);
+  G_SET_OBJECT (msgbox, "canvas_bottom", canvas);
 
   /* ȥꥦåȤ */
   vbox = gtk_vbox_new (FALSE, 0);
@@ -562,26 +564,26 @@ assistant_msgbox_new (GtkWidget		*parent,
   gtk_table_attach (GTK_TABLE (table), vbox, 1, 2, 1, 2,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
-  G_SET_WIDGET (msgbox, "vbox", vbox);
+  G_SET_OBJECT (msgbox, "vbox", vbox);
   {
     widget = gtk_label_new (_("What keyword do you want to know about ?"));
     gtk_widget_show (widget);
     gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
     gtk_widget_set_size_request (widget, -1, 30);
-    G_SET_WIDGET (msgbox, "label1", widget);
+    G_SET_OBJECT (msgbox, "label1", widget);
 
     widget = gtk_entry_new ();
     gtk_widget_show (widget);
     gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);    
     gtk_widget_set_size_request (widget, -1, 22);
     g_object_set_data (G_OBJECT (msgbox), "entry", widget);
-    G_SET_WIDGET (msgbox, "entry", widget);
+    G_SET_OBJECT (msgbox, "entry", widget);
 
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (hbox);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 5);
-    G_SET_WIDGET (msgbox, "hbox", hbox);
+    G_SET_OBJECT (msgbox, "hbox", hbox);
     {
       widget = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
       gtk_widget_show (widget);
@@ -590,7 +592,7 @@ assistant_msgbox_new (GtkWidget		*parent,
       g_signal_connect (G_OBJECT (widget), "clicked",
 			G_CALLBACK (assistant_cb_msg_cancel),
 			(gpointer) msgbox);
-      G_SET_WIDGET (msgbox, "button1", widget);
+      G_SET_OBJECT (msgbox, "button1", widget);
 
       widget = gtk_button_new_from_stock (GTK_STOCK_FIND);
       gtk_widget_ref (widget);          
@@ -600,7 +602,7 @@ assistant_msgbox_new (GtkWidget		*parent,
       g_signal_connect (G_OBJECT (widget), "clicked",
 			G_CALLBACK (assistant_cb_msg_query),
 			(gpointer) msgbox);
-      G_SET_WIDGET (msgbox, "button2", widget);
+      G_SET_OBJECT (msgbox, "button2", widget);
     }
   }
   gdk_window_get_size (skin->msg_box_mask, &w, &h);
@@ -651,7 +653,7 @@ assistant_new (const gchar	*skin_file) {
   gtk_widget_ref  (canvas);
   gtk_widget_show (canvas);
   gtk_container_add (GTK_CONTAINER (window), canvas);
-  G_SET_WIDGET (window, "canvas", canvas);
+  G_SET_OBJECT (window, "canvas", canvas);
 
   gdk_window_get_size (skin->body, &w, &h);
   gtk_widget_set_size_request (window, w, h);
@@ -662,7 +664,7 @@ assistant_new (const gchar	*skin_file) {
 
   /* åܥå */
   msgbox = assistant_msgbox_new (window, skin);
-  G_SET_WIDGET    (window, "msg_box", msgbox);
+  G_SET_OBJECT    (window, "msg_box", msgbox);
   G_SET_PARAMETER (window, "skin",    skin);
   g_signal_connect (G_OBJECT (window), "destroy",
 		    G_CALLBACK (assistant_cb_close), (gpointer) msgbox);
