@@ -1,16 +1,16 @@
 /* ********************************************************** cripping.c *** *
  * Υåԥ
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/05/13 09:17:03 sugaya>
+ *                                    Time-stamp: <05/07/18 04:45:35 sugaya>
  * ************************************************************************* */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include "teoeyes.h"
 #include "cripping.h"
-#include "draw.h"
-#include "image_io.h"
-#include "image_window.h"
-#include "list_viewer.h"
+#include "list_window.h"
 
 /* åԥΰ ************************************************** */
 void
@@ -167,15 +167,15 @@ remove_crip (void) {
 void
 crip_do_crip (void) {
   GtkWidget	*canvas;
-  GdkPixbuf	*pbuf, *tmp;
-  char		buf[256];
-  gint		x, y, w, h, ow, oh, nw, nh;
+  TEImage	*image;
+  GdkPixbuf	*pixbuf, *tmp;
+  gint		x, y, w, h, ow, oh;
 
   /* åȤγ */
   canvas = G_GET_WIDGET (image_window, "canvas");
 
   /* ǡγ */
-  pbuf = ti_get_pixbuf (image_list);
+  pixbuf = ti_get_pixbuf (image_list);
 
   /* åΰγ */
   x  = (gint) G_GET_PARAMETER (image_window, "crip_x");
@@ -184,50 +184,34 @@ crip_do_crip (void) {
   h  = (gint) G_GET_PARAMETER (image_window, "crip_h");
   ow = ti_get_width  (image_list);
   oh = ti_get_height (image_list);
-  nw = ti_get_current_width  (image_list);
-  nh = ti_get_current_height (image_list);
 
   /* åԥ󥰤μ¹ */
-  if (pbuf) {
+  if (pixbuf) {
     if (w > 0 && h > 0) {
-      x = x * ow / nw;
-      y = y * oh / nh;
-      w = w * ow / nw;
-      h = h * oh / nh;
-
       /* åԥ */
       tmp = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
-			    gdk_pixbuf_get_has_alpha (pbuf), 8, w, h);
-      gdk_pixbuf_copy_area (pbuf, x, y, w, h, tmp, 0, 0);
-      sprintf (buf, "cripped-image");
-      teoeyes_image_add_list (g_list_last (image_list), buf, FALSE);
-      
-      /* ȲΥ */
-#if 0
-      if (opt->clear_data && !opt->display_mode) {
-	te_image_clear_image (image_list);
-      }
-#endif
+			    gdk_pixbuf_get_has_alpha (pixbuf), 8, w, h);
+      gdk_pixbuf_copy_area (pixbuf, x, y, w, h, tmp, 0, 0);
+      image = teoeyes_image_new("cripped-image", GNOME_VFS_FILE_MEMORY);
+
       /* åԥ󥰤ꥹȤɲ */
-      image_list = g_list_last (image_list);
-      ti_set_pixbuf (image_list, tmp);
-      teoeyes_image_set (ti_get_image (image_list), 0, 0, 255);      
-#if 0
-      if (!opt->display_mode) {
-	te_image_load_image (image_list, 0, opt->min, opt->max);
-      }
-#endif
+      teoeyes_image_set_memory(image, tmp);
+      image_list = g_list_append(image_list, image);
+      image_list = g_list_last(image_list);
+
       /* 礭 */
       w = (gint) G_GET_PARAMETER (image_window, "crip_w");
       h = (gint) G_GET_PARAMETER (image_window, "crip_h");
 
-      gtk_widget_set_size_request (canvas, w, h);
-      image_window_set_size (image_window, w, h);
+      gtk_window_set_title(GTK_WINDOW(image_window), "cripped_image");
+      image_window_set_size(image_window,
+			    ti_get_width(image_list),
+			    ti_get_height(image_list));
       remove_crip ();
 
       /* ꥹȥɥƤϥͥ򹹿 */
-      if (list_viewer && GTK_WIDGET_VISIBLE (list_viewer)) {
-	list_viewer_refresh_list (list_viewer);
+      if (list_window && GTK_WIDGET_VISIBLE (list_window)) {
+	list_window_refresh_list (list_window);
       }
     }
   }
