@@ -1,13 +1,18 @@
 /* *************************************************************** dnd.c *** *
  * ɥå&ɥå״ؿ
  *
- * Copyright (C) 1998-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 1998-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <03/03/07 23:35:00 sugaya>
+ *                                  Time-stamp: <05/05/05 18:36:51 sugaya>
  * ************************************************************************* */
-#include "teoeyes.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#include <gtk/gtk.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include "dnd.h"
-#include "image_io.h"
 #include "open.h"
 
 /* ɥå׻Υ٥ **************************************************** */
@@ -23,27 +28,11 @@ drop_event (GtkWidget		*widget,
 
   if (!selection_data->data) return;
 
-  if (strncmp (selection_data->data, "file:", 5) == 0) {
-    filename = selection_data->data + 5;
-  } else {
-    filename = selection_data->data;
-  }
+  filename = selection_data->data;
   filename[strlen (filename) - 2] = '\0';
-
-  /* ե뤬¸ߤ뤫ɤĴ٤ */
-  if (!filename || !g_file_exist (filename)) {
-    g_print ("Dont exist %s\n", filename);
-    return;
-  }
-  /* ꤵ줿ե뤬бե뤫ɤĴ٤ */
-  if (!check_image_supported (filename)) {
-    g_print ("Can not support this image type.\n");
-    return;
-  }
-  /* 򳫤 */
-  if (!teoeyes_open_image_on_same_window (filename)) exit (1);
+  teoeyes_open_image_on_same_window (filename);
 }
-
+		     
 /* ɥå¦ ******************************************************** */
 void
 dnd_drop_on_widget (GtkWidget	*widget) {
@@ -62,8 +51,8 @@ dnd_drop_on_widget (GtkWidget	*widget) {
 		     drag_types,
 		     n_drag_types,
 		     GDK_ACTION_COPY);
-  g_signal_connect (G_OBJECT (widget), "drag_data_received",
-		    G_CALLBACK (drop_event), NULL);
+  g_signal_connect (G_OBJECT (widget),
+		    "drag_data_received", G_CALLBACK (drop_event), NULL);
 }
 
 /* ******************************************************** End of dnd.c *** */
