@@ -1,64 +1,62 @@
 /* ************************************************************** draw.c *** *
  * ؿ
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <03/05/02 23:22:56 sugaya>
+ *                                  Time-stamp: <05/06/14 23:14:45 sugaya>
  * ************************************************************************* */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include "teoeyes.h"
-#include "draw.h"
-#include "image_window.h"
 
 /*  ************************************************************** */
 void
 draw_image (GList	*list,
 	    gint	width,
 	    gint	height) {
-  GtkWidget	*canvas;
   GdkWindow	*window;
-  GdkPixbuf	*background, *plane = NULL;
+  GdkPixbuf	*background = NULL;
+  GdkPixbuf	*plane = NULL;
   GdkPixmap	*pixmap;
-  GdkBitmap	*mask;
-
+  GdkBitmap	*mask = NULL;
+  
   /* Хγ */
-  canvas = G_GET_WIDGET (image_window, "canvas");
-  window = canvas->window;
+  window = G_GET_WIDGET(image_window, "canvas")->window;
+
+  /* Хå */
+  gdk_window_set_back_pixmap(window, NULL, FALSE);
 
   /* ץ졼ɽ⡼ */
-  if (ti_get_channel (list) != -1) {
-    plane = ti_get_nth_plane (list, ti_get_channel (list));
+  if (ti_get_channel(list) != -1) {
+    plane = ti_get_nth_plane (list, ti_get_channel(list));
   }
-  /* Хå */
-  gdk_window_set_back_pixmap (window, NULL, FALSE);
-  background = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, width, height);
+  if (!(pixmap = ti_get_pixmap(list) ) || plane) {
+    background = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, width, height);
 
-  /*  */
-  gdk_pixbuf_composite_color ((plane) ? plane : ti_get_pixbuf (list),
-			      background,
-			      0, 0,
-			      width, height,
-			      0, 0,
-			      (gdouble) width  / ti_get_width  (list),
-			      (gdouble) height / ti_get_height (list),
-			      GDK_INTERP_TILES,
-			      255,
-			      0, 0,
-			      16, 0xaaaaaa, 0x555555);
+    /*  */
+    gdk_pixbuf_composite_color((plane) ? plane : ti_get_pixbuf(list),
+			       background,
+			       0, 0, width, height, 0, 0, 1.0, 1.0,
+			       GDK_INTERP_TILES,
+			       255,
+			       0, 0,
+			       16, 0xaaaaaa, 0x555555);
+    /* ԥåޥåפ */
+    gdk_pixbuf_render_pixmap_and_mask(background, &pixmap, &mask, 255);
+  }
   /* ɥؤ */
+  gdk_window_set_back_pixmap(window, pixmap, FALSE);
+  gdk_window_clear(window);
+  gdk_window_shape_combine_mask(window, mask, 0, 0);
+  gdk_flush();
 
-  /* ԥåޥåפ */
-  gdk_pixbuf_render_pixmap_and_mask (background, &pixmap, &mask, 255);
-
-  /* ɥؤ */
-  gdk_window_set_back_pixmap (window, pixmap, FALSE);
-  gdk_window_clear (window);
-  gdk_window_shape_combine_mask (window, mask, 0, 0);
-  gdk_flush ();
-
-  gdk_pixbuf_unref (background);
-  gdk_pixmap_unref (pixmap);
-  if (mask)  gdk_bitmap_unref (mask);
-  if (plane) gdk_pixbuf_unref (plane);
+  if (background) {
+    gdk_pixbuf_unref(background);
+    gdk_pixmap_unref(pixmap);
+  }
+  if (plane) gdk_pixbuf_unref(plane);
+  if (mask)  gdk_bitmap_unref(mask);
 }
 
 /* ΰȤ ******************************************************** */
