@@ -1,9 +1,9 @@
 /* ********************************************** gdk-pixbuf-extension.c *** *
  * gdk-pixbufγĥؿ
  *
- * Copyright (C) 2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp
+ * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp
  * Okayama University
- *                                  Time-stamp: <03/02/03 22:14:50 sugaya>
+ *                                  Time-stamp: <05/03/03 21:35:03 sugaya>
  *
  * eel-gdk-pixbuf-extensions.c: Routines to augment what's in gdk-pixbuf.
  *
@@ -41,19 +41,6 @@ gdk_pixbuf_free_buffer (guchar	*pixels,
   g_free (pixels);
 }
 
-/* ************************************************************************* */
-void
-gdk_pixbuf_copy2 (const GdkPixbuf	*src,
-		  GdkPixbuf		*dst) {
-  int size;
-
-  size = ((gdk_pixbuf_get_height (src) - 1) * gdk_pixbuf_get_rowstride (src) +
-	  gdk_pixbuf_get_width (src) * 
-	  ((gdk_pixbuf_get_n_channels (src) *
-	    gdk_pixbuf_get_bits_per_sample (src) + 7) / 8));
-  memcpy (gdk_pixbuf_get_pixels (dst), gdk_pixbuf_get_pixels (src), size);
-}
-
 /* ץ졼ĥǡǡǡ ********** */
 GdkPixbuf*
 gdk_pixbuf_remove_alpha (const GdkPixbuf	*src) {
@@ -102,11 +89,7 @@ gdk_pixbuf_calc_map_tables (GdkPixbufModifier		*mod) {
     return;
   }
   if (!mod->map) {
-#if 0 
-   mod->map = (GdkPixbufModifierMap *) malloc (sizeof (GdkPixbufModifierMap));
-#else
    mod->map = g_new (GdkPixbufModifierMap, 1);
-#endif
     if (!mod->map) return;
   }
   g = ((gdouble) mod->mod.gamma)      / 256;
@@ -355,7 +338,7 @@ gdk_pixbuf_apply_modifiers_to_rgb (GdkPixbuf			*pbuf,
     gdk_pixbuf_calc_map_tables (mod);
   }
 }
-
+#if 0
 /* ************************************************************************* */
 GdkPixbuf*
 gdk_pixbuf_align_rowstride (GdkPixbuf	*src) {
@@ -392,5 +375,109 @@ gdk_pixbuf_align_rowstride (GdkPixbuf	*src) {
 				     gdk_pixbuf_free_buffer, NULL);
   }
 }
+#endif
+/* ************************************************************************* */
+GdkPixbuf*
+gdk_pixbuf_copy_rotate_90 (GdkPixbuf	*src, 
+			   gboolean	counter_clockwise) {
+  GdkPixbuf	*dest;
+  int		has_alpha;
+  int		sw, sh, srs;
+  int		dw, dh, drs;
+  guchar	*s_pix;
+  guchar	*d_pix;
+  guchar	*sp;
+  guchar	*dp;
+  int		i, j, a;
+
+  if (!src) return NULL;
+
+  sw = gdk_pixbuf_get_width  (src);
+  sh = gdk_pixbuf_get_height (src);
+  has_alpha = gdk_pixbuf_get_has_alpha (src);
+  srs   = gdk_pixbuf_get_rowstride (src);
+  s_pix = gdk_pixbuf_get_pixels (src);
+
+  dw = sh;
+  dh = sw;
+  dest  = gdk_pixbuf_new (GDK_COLORSPACE_RGB, has_alpha, 8, dw, dh);
+  drs   = gdk_pixbuf_get_rowstride (dest);
+  d_pix = gdk_pixbuf_get_pixels (dest);
+
+  a = (has_alpha ? 4 : 3);
+
+  for (i = 0; i < sh; i++) {
+    sp = s_pix + (i * srs);
+    for (j = 0; j < sw; j++) {
+      if (counter_clockwise) {
+	dp = d_pix + ((dh - j - 1) * drs) + (i * a);
+      } else {
+	dp = d_pix + (j * drs) + ((dw - i - 1) * a);
+      }
+      *(dp++) = *(sp++);		/* r */
+      *(dp++) = *(sp++);		/* g */
+      *(dp++) = *(sp++);		/* b */
+      if (has_alpha) *(dp) = *(sp++);	/* a */
+    }
+  }
+  return dest;
+}
+
+/* ************************************************************************* */
+GdkPixbuf*
+gdk_pixbuf_copy_mirror (GdkPixbuf	*src, 
+			gboolean	mirror, 
+			gboolean	flip) {
+  GdkPixbuf	*dest;
+  int		has_alpha;
+  int		w, h, srs;
+  int		drs;
+  guchar	*s_pix;
+  guchar	*d_pix;
+  guchar	*sp;
+  guchar	*dp;
+  int		i, j, a;
+
+  if (!src) return NULL;
+
+  w = gdk_pixbuf_get_width  (src);
+  h = gdk_pixbuf_get_height (src);
+  has_alpha = gdk_pixbuf_get_has_alpha (src);
+  srs   = gdk_pixbuf_get_rowstride (src);
+  s_pix = gdk_pixbuf_get_pixels (src);
+
+  dest  = gdk_pixbuf_new (GDK_COLORSPACE_RGB, has_alpha, 8, w, h);
+  drs   = gdk_pixbuf_get_rowstride (dest);
+  d_pix = gdk_pixbuf_get_pixels (dest);
+
+  a = has_alpha ? 4 : 3;
+
+  for (i = 0; i < h; i++)	{
+    sp = s_pix + (i * srs);
+    if (flip) {
+      dp = d_pix + ((h - i - 1) * drs);
+    } else {
+      dp = d_pix + (i * drs);
+    }
+    if (mirror) {
+      dp += (w - 1) * a;
+      for (j = 0; j < w; j++) {
+	*(dp++) = *(sp++);		/* r */
+	*(dp++) = *(sp++);		/* g */
+	*(dp++) = *(sp++);		/* b */
+	if (has_alpha) *(dp) = *(sp++);	/* a */
+	dp -= (a + 3);
+      }
+    } else {
+      for (j = 0; j < w; j++) {
+	*(dp++) = *(sp++);		/* r */
+	*(dp++) = *(sp++);		/* g */
+	*(dp++) = *(sp++);		/* b */
+	if (has_alpha) *(dp++) = *(sp++);	/* a */
+      }
+    }
+  }
+  return dest;
+}
 
 /* *************************************** End of gdk-pixbuf-extension.c *** */
