@@ -1,9 +1,9 @@
 /* ********************************************** gdk-pixbuf-extension.h *** *
  * gdk-pixbufγĥؿ إåե
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/03/27 16:05:15 sugaya>
+ *                                    Time-stamp: <05/03/03 21:35:19 sugaya>
  * ************************************************************************* */
 #ifndef	__GDK_PIXBUF_EXTENSION_H__
 #define	__GDK_PIXBUF_EXTENSION_H__
@@ -83,8 +83,17 @@ void
 gdk_pixbuf_apply_modifiers_to_rgb 	(GdkPixbuf		*pbuf,
 					 GdkPixbufModifier	*mod,
 					 gboolean		clear_flg);
+#if 0
 GdkPixbuf*
 gdk_pixbuf_align_rowstride		(GdkPixbuf		*src);
+#endif
+GdkPixbuf*
+gdk_pixbuf_copy_rotate_90 		(GdkPixbuf		*src, 
+					 gboolean		counter_clockwise);
+GdkPixbuf*
+gdk_pixbuf_copy_mirror 			(GdkPixbuf		*src, 
+					 gboolean		mirror, 
+					 gboolean		flip);
 
 #endif	/* __GDK_PIXBUF_EXTENSION_H__ */
 
