@@ -1,16 +1,19 @@
 /* ************************************************************** grab.c *** *
  * Υ
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <03/05/14 23:23:44 sugaya>
+ *                                  Time-stamp: <05/07/20 11:38:12 sugaya>
  * ************************************************************************* */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#include <gdk/gdkx.h>
+#include <gdk/gdkprivate.h>
+#include <X11/cursorfont.h>
 #include "teoeyes.h"
-#include "X11/cursorfont.h"
 #include "grab.h"
-#include "image_io.h"
-#include "image_window.h"
-#include "list_viewer.h"
+#include "list_window.h"
 
 /* Хѿ ********************************************************** */
 static Display		*dsp;
@@ -131,7 +134,7 @@ grab_do_grab (void) {
   Window		rW, cW, clickW, chwin, orgW;
   XWindowAttributes	clickxwa, parentxwa;  
   Cursor		tcross;
-  char			buf[256];  
+  TEImage		*image;
   unsigned int		mask;
   int			n, x, y, rx, ry, rw, rh, x1, y1, x2, y2;
   int			ix, iy, iw, ih, W, H, org_x, org_y;
@@ -233,30 +236,20 @@ grab_do_grab (void) {
     pixbuf = gdk_pixbuf_align_rowstride (tmp);
     gdk_pixbuf_unref (tmp);
 
-    sprintf (buf, "grabed-image");
-    teoeyes_image_add_list (g_list_last (image_list), buf, FALSE);
-
-    /* ȲΥ */
-#if 0
-    if (opt->clear_data && !opt->display_mode) {
-      image_clear_image (image_list);
-    }
-#endif
+    image = teoeyes_image_new("grabed-image", GNOME_VFS_FILE_MEMORY);
+    teoeyes_image_set_memory(image, pixbuf);
+    image_list = g_list_append(image_list, image);
     image_list = g_list_last (image_list);
-    ti_set_pixbuf (image_list, pixbuf);
-    teoeyes_image_set (ti_get_image (image_list), 0, 0, 255);      
-#if 0    
-    if (!opt->display_mode) {
-      image_load_image (image_list, 0, opt->min, opt->max);
-    }
-#endif
+
     /* 礭 */
-    gtk_widget_set_size_request (canvas, iw, ih);
-    image_window_set_size (image_window, iw, ih);
+    gtk_window_set_title(GTK_WINDOW(image_window), "cripped_image");
+    image_window_set_size(image_window,
+			  ti_get_width(image_list),
+			  ti_get_height(image_list));
 
     /* ꥹȥɥƤϥͥ򹹿 */
-    if (list_viewer && GTK_WIDGET_VISIBLE (list_viewer)) {
-      list_viewer_refresh_list (list_viewer);
+    if (list_window && GTK_WIDGET_VISIBLE (list_window)) {
+      list_window_refresh_list (list_window);
     }
   } else if (mask & Button1Mask) {
     /* ܥΥ٥ (ΰΥ) */
@@ -301,30 +294,20 @@ grab_do_grab (void) {
     pixbuf = gdk_pixbuf_align_rowstride (tmp);
     gdk_pixbuf_unref (tmp);
 
-    sprintf (buf, "grabed-image");
-    teoeyes_image_add_list (g_list_last (image_list), buf, FALSE);
-
-    /* ȲΥ */
-#if 0
-    if (opt->clear_data && !opt->display_mode) {
-      image_clear_image (image_list);
-    }
-#endif
+    image = teoeyes_image_new("grabed-image", GNOME_VFS_FILE_MEMORY);
+    teoeyes_image_set_memory(image, pixbuf);
+    image_list = g_list_append(image_list, image);
     image_list = g_list_last (image_list);
-    ti_set_pixbuf (image_list, pixbuf);
-    teoeyes_image_set (ti_get_image (image_list), 0, 0, 255);
-#if 0
-    if (!opt->display_mode) {
-      image_load_image (image_list, 0, opt->min, opt->max);
-    }
-#endif
+
     /* 礭 */
-    gtk_widget_set_size_request (canvas, iw, ih);
-    image_window_set_size (image_window, iw, ih);
+    gtk_window_set_title(GTK_WINDOW(image_window), "cripped_image");
+    image_window_set_size(image_window,
+			  ti_get_width(image_list),
+			  ti_get_height(image_list));
 
     /* ꥹȥɥƤϥͥ򹹿 */
-    if (list_viewer && GTK_WIDGET_VISIBLE (list_viewer)) {
-      list_viewer_refresh_list (list_viewer);
+    if (list_window && GTK_WIDGET_VISIBLE (list_window)) {
+      list_window_refresh_list (list_window);
     }
   }
 }
