@@ -1,9 +1,9 @@
 /* **************************************************** gtkdirtreeview.c *** *
  * GtkDirTreeView
  *
- * Copyright (C) 2002-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2002-2005 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/03/12 20:18:27 sugaya>
+ *                                    Time-stamp: <05/04/02 02:48:03 sugaya>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -28,9 +28,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 #include "gtkdirtreeview.h"
-#include "gfileutils.h"
-#include "default.icon"
+#include "gnome-vfs-extension.h"
+#include "gtkdirtreeview-default-icons.h"
+#include "glib-fileutil-extension.h"
 
 #ifndef GTK_DISABLE_DEPRECATED
 #define	GTK_DISABLE_DEPRECATED
@@ -629,16 +631,23 @@ cb_expand (GtkDirTreeView	*treeview,
 
   gtk_tree_model_get (GTK_TREE_MODEL (store),
 		      parent_iter, COLUMN_PATH, &parent_dir,COLUMN_TERMINATOR);
+  dir_list = gnome_vfs_ext_ls_dir (parent_dir);
 
-  dir_list = g_dir_ls_dir (parent_dir, treeview->show_hidden);
-		
   if (dir_list) {
     for (list = dir_list; list; list = g_list_next (list)) {
-      path = g_build_filename (parent_dir, (gchar *) list->data, NULL);
-      insert_row (store, &iter, parent_iter, (gchar *) list->data, path);
+      if ((strcmp (((GnomeVFSFileInfo *) list->data)->name, ".")  == 0) ||
+	  (strcmp (((GnomeVFSFileInfo *) list->data)->name, "..") == 0) ||
+	  (((GnomeVFSFileInfo *) list->data)->type
+	   != GNOME_VFS_FILE_TYPE_DIRECTORY) ||
+	  (!treeview->show_hidden &&
+	   ((GnomeVFSFileInfo *) list->data)->name[0] == '.')) continue;
+      path = g_build_filename (parent_dir,
+			       ((GnomeVFSFileInfo *) list->data)->name, NULL);
+      insert_row (store, &iter, parent_iter,
+		  ((GnomeVFSFileInfo *) list->data)->name, path);
       g_free (path);
     }
-    g_list_free (dir_list);
+    gnome_vfs_file_info_list_free (dir_list);
   }
   gtk_tree_store_remove (store, &child_iter);
 }
