@@ -3,11 +3,13 @@
  *
  * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                     Time-stamp: <03/06/28 12:21:54 sugaya>
+ *                                     Time-stamp: <05/04/19 00:51:57 sugaya>
  *
  * The original source code came from gthumb-2.1.2
  * ************************************************************************* */
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 #include <string.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeprint/gnome-print.h>
@@ -18,7 +20,6 @@
 #include <libgnomeprintui/gnome-print-paper-selector.h>
 #include <libgnomecanvas/libgnomecanvas.h>
 #include <libart_lgpl/libart.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <pango/pango-layout.h>
 #include "teoeyes.h"
 #include "print-callbacks.h"
@@ -1055,7 +1056,7 @@ print_dialog_show (GtkWindow	*parent,
   pi->zoom = 1.0;
 
   pi->config	 = gnome_print_config_default ();
-  pi->image_path = g_strdup (ti_get_file_path (list));
+  pi->image_path = g_strdup (ti_get_uri (list));
   pi->filename	 = (gchar *) ti_get_filename (list);
   pi->pixbuf	 = gdk_pixbuf_copy (ti_get_pixbuf (list));
 
@@ -1082,8 +1083,7 @@ print_dialog_show (GtkWindow	*parent,
 
   gtk_window_set_transient_for (GTK_WINDOW (data->dialog), parent);
 
-  gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (pi->canvas), 
-				    CANVAS_ZOOM);
+  gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (pi->canvas), CANVAS_ZOOM);
   page_update (data);
 
   gtk_widget_show (data->dialog);
